# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.billing_type import BillingType

class TestBillingType(unittest.TestCase):
    """BillingType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBillingType(self):
        """Test BillingType"""
        # inst = BillingType()

if __name__ == '__main__':
    unittest.main()
