# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.ipn_order_payment import IpnOrderPayment

class TestIpnOrderPayment(unittest.TestCase):
    """IpnOrderPayment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IpnOrderPayment:
        """Test IpnOrderPayment
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IpnOrderPayment`
        """
        model = IpnOrderPayment()
        if include_optional:
            return IpnOrderPayment(
                marketplace_buyer = public_api_server_connector_v2.models.marketplace_buyer.MarketplaceBuyer(
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    phone_number = '', 
                    address = null, ),
                course_ids = [
                    56
                    ],
                id = '',
                transaction = public_api_server_connector_v2.models.ipn_transaction.IpnTransaction(
                    amount = 1.337, 
                    id = '', ),
                send_email = True,
                billing_type = 'single_payment',
                access_until = 56,
                occurred_at = 56
            )
        else:
            return IpnOrderPayment(
                marketplace_buyer = public_api_server_connector_v2.models.marketplace_buyer.MarketplaceBuyer(
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    phone_number = '', 
                    address = null, ),
                course_ids = [
                    56
                    ],
        )
        """

    def testIpnOrderPayment(self):
        """Test IpnOrderPayment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
