# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.mediastorage_api import MediastorageApi


class TestMediastorageApi(unittest.IsolatedAsyncioTestCase):
    """MediastorageApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MediastorageApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_key_auth_create_folder(self) -> None:
        """Test case for api_key_auth_create_folder

        Create Folder
        """
        pass

    async def test_api_key_auth_delete_file(self) -> None:
        """Test case for api_key_auth_delete_file

        Delete File
        """
        pass

    async def test_api_key_auth_delete_folder(self) -> None:
        """Test case for api_key_auth_delete_folder

        Delete Folder
        """
        pass

    async def test_api_key_auth_get_all_files_count(self) -> None:
        """Test case for api_key_auth_get_all_files_count

        Get All Files Count
        """
        pass

    async def test_api_key_auth_get_all_folders(self) -> None:
        """Test case for api_key_auth_get_all_folders

        Get All Folders
        """
        pass

    async def test_api_key_auth_get_all_folders_count(self) -> None:
        """Test case for api_key_auth_get_all_folders_count

        Get All Folders Count
        """
        pass

    async def test_api_key_auth_get_file(self) -> None:
        """Test case for api_key_auth_get_file

        Get File
        """
        pass

    async def test_api_key_auth_get_files(self) -> None:
        """Test case for api_key_auth_get_files

        Get Files
        """
        pass

    async def test_api_key_auth_get_files_all(self) -> None:
        """Test case for api_key_auth_get_files_all

        Get Files All
        """
        pass

    async def test_api_key_auth_get_files_count(self) -> None:
        """Test case for api_key_auth_get_files_count

        Get Files Count
        """
        pass

    async def test_api_key_auth_get_folder(self) -> None:
        """Test case for api_key_auth_get_folder

        Get Folder
        """
        pass

    async def test_api_key_auth_get_folders(self) -> None:
        """Test case for api_key_auth_get_folders

        Get Folders
        """
        pass

    async def test_api_key_auth_get_folders_count(self) -> None:
        """Test case for api_key_auth_get_folders_count

        Get Folders Count
        """
        pass

    async def test_api_key_auth_update_file(self) -> None:
        """Test case for api_key_auth_update_file

        Update File
        """
        pass

    async def test_api_key_auth_update_folder(self) -> None:
        """Test case for api_key_auth_update_folder

        Update Folder
        """
        pass

    async def test_api_key_auth_upload_file(self) -> None:
        """Test case for api_key_auth_upload_file

        Upload File
        """
        pass


if __name__ == '__main__':
    unittest.main()
