# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.ipn_order_refund import IpnOrderRefund

class TestIpnOrderRefund(unittest.TestCase):
    """IpnOrderRefund unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IpnOrderRefund:
        """Test IpnOrderRefund
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IpnOrderRefund`
        """
        model = IpnOrderRefund()
        if include_optional:
            return IpnOrderRefund(
                id = '',
                transaction = public_api_server_connector_v2.models.ipn_transaction.IpnTransaction(
                    amount = 1.337, 
                    id = '', )
            )
        else:
            return IpnOrderRefund(
                id = '',
        )
        """

    def testIpnOrderRefund(self):
        """Test IpnOrderRefund"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
