# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BillingType(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    SINGLE_PAYMENT = 'single_payment'
    SUBSCRIPTION = 'subscription'
    INSTALLMENT = 'installment'
    FREE = 'free'
    FAKE = 'fake'
    GIFT = 'gift'
    SINGLE_PAYMENT_IMPORTED = 'single_payment_imported'
    SUBSCRIPTION_IMPORTED = 'subscription_imported'
    INSTALLMENT_IMPORTED = 'installment_imported'
    FREE_IMPORTED = 'free_imported'
    FAKE_IMPORTED = 'fake_imported'
    GIFT_IMPORTED = 'gift_imported'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BillingType from a JSON string"""
        return cls(json.loads(json_str))


